@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2004-2006 Johan Svedberg <johan@svedberg.com>
+# Copyright (C) 2004-2007 Johan Svedberg <johan@svedberg.com>
 
 # This file is part of ontv.
 
@@ -20,26 +20,37 @@
 
 import datetime
 import os.path
+import thread
+import urllib
+import sys
 from gettext import gettext as _
 
+import gtk
 import gtk.gdk
 import gobject
 
-from GUI import ErrorDialog
+import GUI
+from ontv import IMAGES_DIR
 
 class Channel:
-    def __init__(self, channel):
+    def __init__(self, channel, xmltvfile):
         self.id = channel["id"]
         self.name = self.__get_name(channel)
         self.markup_escaped_name = gobject.markup_escape_text(self.name)
+        self.icon = self.__get_icon(channel)
 
         self.logo_file = ""
         self.logo = None
         self.logo_small = None
+        self.custom_logo = False
 
         self.selected = False
         self.programs = []
 
+        if self.icon and not xmltvfile.listings.channel_has_custom_logo(self):
+            thread.start_new_thread(self.__download_logo, (self.icon,
+                                                           xmltvfile,))
+
     def __cmp__(self, other):
         return cmp(self.name, other.name)
 
@@ -63,13 +74,47 @@ class Channel:
             return unicode(channel["display-name"][0][0]).encode("utf-8")
         return None
 
-    def set_logo(self, file_name):
+    def __get_icon(self, channel):
+        if channel.has_key("icon"):
+            return channel["icon"][0]["src"]
+        return None
+
+    def __download_logo(self, icon, xmltvfile):
+        self.set_logo(os.path.join(IMAGES_DIR, "ontv-logo-downloading.png"))
+        gtk.gdk.threads_enter()
+        xmltvfile.emit("downloading-logo", (self))
+        gtk.gdk.threads_leave()
+        config = xmltvfile.config
+
+        if config.debug:
+            print("Downloading logo for channel \"%s\" from:\n%s..." %
+                  (self.name, icon))
+        try:
+            file = os.path.join(config.logos_dir, os.path.basename(icon))
+            (self.logo_file, headers) = urllib.urlretrieve(icon, file)
+
+        except IOError, ioe:
+            print >> sys.stderr, "Unable to download logo for channel \
+                                  \"%s\" from:\n%s: %s" % (self.name, icon,
+                                 ioe.strerror)
+
+        self.set_logo(self.logo_file)
+        gtk.gdk.threads_enter()
+        xmltvfile.emit("downloading-logo-done", (self))
+        gtk.gdk.threads_leave()
+
+    def set_logo(self, file_name, silent=True):
         if os.path.exists(file_name):
             try:
                 logo_pixbuf = gtk.gdk.pixbuf_new_from_file(file_name)
             except gobject.GError, ge:
-                ed = ErrorDialog(_("Error while loading ") + file_name,
-                                 ge.message)
+                if silent:
+                    self.logo = None
+                    self.logo_small = None
+                    return
+                self.custom_logo = False
+                ed = GUI.ErrorDialog(_("Error while loading %s" % file_name),
+                                     ge.message)
                 ed.run()
                 ed.destroy()
                 return
