@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2004-2006 Johan Svedberg <johan@svedberg.com>
+# Copyright (C) 2004-2007 Johan Svedberg <johan@svedberg.com>
 
 # This file is part of ontv.
 
@@ -28,23 +28,21 @@ from GUI import ErrorDialog
 
 DIR_ONTV = "/apps/ontv"
 
-KEY_XMLTV_FILE                  = "/general/xmltv_file"
-KEY_AUTO_RELOAD_XMLTV_FILE      = "/general/auto_reload_xmltv_file"
-KEY_AUTO_RELOAD_XMLTV_FILE_RATE = "/general/auto_reload_xmltv_file_rate"
+KEY_GRABBER_COMMAND             = "/general/grabber_command"
+KEY_CONFIGURED_GRABBERS         = "/general/configured_grabbers"
 KEY_DISPLAY_CURRENT_PROGRAMS    = "/general/display_current_programs"
 KEY_DISPLAY_UPCOMING_PROGRAMS   = "/general/display_upcoming_programs"
 KEY_ENABLE_HOTKEYS              = "/general/enable_hotkeys"
 KEY_SHOW_WINDOW_HOTKEY          = "/general/show_window_hotkey"
 KEY_SHOW_SEARCH_PROGRAM_HOTKEY  = "/general/show_search_program_hotkey"
 
-FUNCTION_SUFFIXES = {KEY_XMLTV_FILE: 'string',
-                     KEY_AUTO_RELOAD_XMLTV_FILE: 'bool',
-                     KEY_AUTO_RELOAD_XMLTV_FILE_RATE: 'int',
-                     KEY_DISPLAY_CURRENT_PROGRAMS: 'bool',
-                     KEY_DISPLAY_UPCOMING_PROGRAMS: 'bool',
-                     KEY_ENABLE_HOTKEYS: 'bool',
-                     KEY_SHOW_WINDOW_HOTKEY: 'string',
-                     KEY_SHOW_SEARCH_PROGRAM_HOTKEY: 'string'}
+FUNCTION_SUFFIXES = {KEY_GRABBER_COMMAND:             'string',
+                     KEY_CONFIGURED_GRABBERS:         'list',
+                     KEY_DISPLAY_CURRENT_PROGRAMS:    'bool',
+                     KEY_DISPLAY_UPCOMING_PROGRAMS:   'bool',
+                     KEY_ENABLE_HOTKEYS:              'bool',
+                     KEY_SHOW_WINDOW_HOTKEY:          'string',
+                     KEY_SHOW_SEARCH_PROGRAM_HOTKEY:  'string'}
 
 class Configuration(object):
     """Singleton representing the configuration"""
@@ -59,8 +57,9 @@ class Configuration(object):
 
     def __init(self, *args):
         self.base_dir = os.path.expanduser("~/.gnome2/ontv")
-        if not os.path.exists(self.base_dir):
-            os.mkdir(self.base_dir)
+        self.logos_dir = os.path.join(self.base_dir, "logos")
+        if not os.path.exists(self.logos_dir):
+            os.makedirs(self.logos_dir)
 
         self.client = gconf.client_get_default()
         if self.client.dir_exists(DIR_ONTV):
@@ -105,41 +104,30 @@ class Configuration(object):
                     FUNCTION_SUFFIXES[option])(DIR_ONTV + option, value)
             self.option_cache[option] = value
 
-    def get_xmltv_file(self, use_cache=True):
+    def get_grabber_command(self, use_cache=True):
         if use_cache:
-            return self.option_cache[KEY_XMLTV_FILE]
+            return self.option_cache[KEY_GRABBER_COMMAND]
         else:
-            return self.__get_option(KEY_XMLTV_FILE)
+            return self.__get_option(KEY_GRABBER_COMMAND)
 
-    def set_xmltv_file(self, xmltv_file):
-        self.__set_option(KEY_XMLTV_FILE, xmltv_file)
+    def set_grabber_command(self, grabber_command):
+        self.__set_option(KEY_GRABBER_COMMAND, grabber_command)
 
-    xmltv_file = property(get_xmltv_file, set_xmltv_file)
+    grabber_command = property(get_grabber_command, set_grabber_command)
 
-    def get_auto_reload_xmltv_file(self, use_cache=True):
+    def get_configured_grabbers(self, use_cache=True):
         if use_cache:
-            return self.option_cache[KEY_AUTO_RELOAD_XMLTV_FILE]
+            return self.option_cache[KEY_CONFIGURED_GRABBERS]
         else:
-            return self.__get_option(KEY_AUTO_RELOAD_XMLTV_FILE)
+            return self.__get_option(KEY_CONFIGURED_GRABBERS,
+                                     gconf.VALUE_STRING)
 
-    def set_auto_reload_xmltv_file(self, auto_reload_xmltv_file):
-        self.__set_option(KEY_AUTO_RELOAD_XMLTV_FILE, auto_reload_xmltv_file)
+    def set_configured_grabbers(self, configured_grabbers):
+        self.__set_option(KEY_CONFIGURED_GRABBERS, configured_grabbers,
+                          gconf.VALUE_STRING)
 
-    auto_reload_xmltv_file = property(get_auto_reload_xmltv_file,
-                                      set_auto_reload_xmltv_file)
-
-    def get_auto_reload_xmltv_file_rate(self, use_cache=True):
-        if use_cache:
-            return self.option_cache[KEY_AUTO_RELOAD_XMLTV_FILE_RATE]
-        else:
-            return self.__get_option(KEY_AUTO_RELOAD_XMLTV_FILE_RATE)
-
-    def set_auto_reload_xmltv_file_rate(self, auto_reload_xmltv_file_rate):
-        self.__set_option(KEY_AUTO_RELOAD_XMLTV_FILE_RATE,
-                          auto_reload_xmltv_file_rate)
-
-    auto_reload_xmltv_file_rate = property(get_auto_reload_xmltv_file_rate,
-                                           set_auto_reload_xmltv_file_rate)
+    configured_grabbers = property(get_configured_grabbers,
+                                   set_configured_grabbers)
 
     def get_enable_hotkeys(self, use_cache=True):
         if use_cache:
