@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2004-2006 Johan Svedberg <johan@svedberg.com>
+# Copyright (C) 2004-2007 Johan Svedberg <johan@svedberg.com>
 
 # This file is part of ontv.
 
@@ -16,12 +16,15 @@
 
 # You should have received a copy of the GNU General Public License
 # along with ontv; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 from gettext import gettext as _
+import gettext
 
 import gtk
+import gtk.gdk
 import gobject
+import pango
 
 import GUI
 from Configuration import Configuration
@@ -30,24 +33,33 @@ from Notification import Notification
 
 TIMEOUT = 60000
 
-class ProgramTable(gtk.Frame):
+class ProgramTable(gtk.VBox):
     def __init__(self, listings, title):
         title= "<span size=\"larger\" weight=\"bold\">%s</span>" % title
-        gtk.Frame.__init__(self, title)
+        gtk.VBox.__init__(self, False, 6)
         self.listings = listings
         self.tooltips = gtk.Tooltips()
 
+        self.label = gtk.Label(title)
+        self.label.set_use_markup(True)
+        self.label.set_padding(3, 3)
+
+        label_box = gtk.HBox(False, 6)
+        label_box.pack_start(self.label, False, False, 0)
+
+        event_box = gtk.EventBox()
+        event_box.add(label_box)
+        style = event_box.get_style()
+        event_box_bg = style.bg[gtk.STATE_INSENSITIVE]
+        event_box.modify_bg(gtk.STATE_NORMAL, event_box_bg)
+
         self.table = gtk.Table()
         self.table.set_border_width(6)
         self.table.props.row_spacing = 2
         self.table.props.column_spacing = 6
 
-        label = self.get_label_widget()
-        label.set_use_markup(True)
-        self.set_border_width(3)
-        self.set_label_align(0.5, 0.5)
-        self.set_shadow_type(gtk.SHADOW_NONE)
-        self.add(self.table)
+        self.pack_start(event_box)
+        self.pack_start(self.table)
 
         self.filled_programs = []
         self.update_ids = []
@@ -116,6 +128,8 @@ class ProgramTable(gtk.Frame):
 
     def __add_program(self, program, column, row):
         label = gtk.Label()
+        label.set_ellipsize(pango.ELLIPSIZE_END)
+        label.set_max_width_chars(80)
         label.set_label(program.title)
         label.set_alignment(0.0, 0.5)
         label.show()
@@ -134,7 +148,7 @@ class ProgramTable(gtk.Frame):
 
 class CurrentProgramTable(ProgramTable):
     def __init__(self, listings):
-        self.title = _("Current programs")
+        self.title = _("Now Playing...")
         ProgramTable.__init__(self, listings, self.title)
 
     def set_programs(self):
@@ -161,29 +175,21 @@ class ProgramBar:
         return (duration.seconds / 60) % 60
 
     def get_readable_time(self, duration):
-        descs = []
-
         hours = self.get_hours(duration)
-        if hours > 0:
-            s = _("%s hour") % str(hours)
-            if not hours is 1:
-                s = _("%s hours") % str(hours)
-            descs.append(s)
-
         minutes = self.get_minutes(duration)
-        if minutes > 0:
-            s = _("%s minute") % str(minutes)
-            if not minutes is 1:
-                s = _("%s minutes") % str(minutes)
-            descs.append(s)
-
-        if len(descs) == 0:
-            s = _("%s second") % str(duration.seconds)
-            if not duration.seconds is 1:
-                s = _("%s seconds") % str(duration.seconds)
-            descs.append(s)
-
-        return _(" and ").join(descs)
+        if hours > 0 and minutes > 0:
+            h = gettext.ngettext("%d hour", "%d hours", hours) % hours
+            m = gettext.ngettext("%d minute", "%d minutes", minutes) % minutes
+            return _("%s and %s left") % (h, m)
+        elif hours > 0 and minutes == 0:
+            return gettext.ngettext("%d hour left", "%d hours left", hours) % \
+                                    hours
+        elif hours == 0 and minutes > 0:
+            return gettext.ngettext("%d minute left", "%d minutes left",
+                                    minutes) % minutes
+        else:
+            return gettext.ngettext("%d second left", "%d seconds left",
+                                    duration.seconds) % duration.seconds
 
 class ProgramProgressBar(ProgramBar, gtk.EventBox):
     def __init__(self, program):
@@ -207,7 +213,7 @@ class ProgramProgressBar(ProgramBar, gtk.EventBox):
         total = self.__time_delta_to_seconds(duration)
         time_until_stop = self.program.get_time_until_stop()
         readable_time = self.get_readable_time(time_until_stop)
-        self.tooltips.set_tip(self, _("%s left") % readable_time)
+        self.tooltips.set_tip(self, readable_time)
         ratio = float(played) / float(total)
         if ratio > 1 or ratio < 0:
             return False
@@ -248,7 +254,7 @@ class ProgramTimeLeftBar(ProgramBar, gtk.Label):
     def update(self):
         time_until_start = self.program.get_time_until_start()
         readable_time = self.get_readable_time(time_until_start)
-        self.set_label(_("%s left") % readable_time)
+        self.set_label(readable_time)
         if self.reminders.has_reminder(Reminder(self.program)):
             Notification(self.program, self.get_readable_time)
         return True
@@ -256,7 +262,7 @@ class ProgramTimeLeftBar(ProgramBar, gtk.Label):
 class ProgramWindow(gtk.Window):
     def __init__(self, xmltvfile, applet, get_docking_data):
         gtk.Window.__init__(self, gtk.WINDOW_TOPLEVEL)
-        xmltvfile.connect("loaded", self.__xmltvfile_loaded)
+        xmltvfile.connect("loading-done", self.__xmltvfile_loading_done)
         self.applet = applet
         self.get_docking_data = get_docking_data
 
@@ -271,7 +277,7 @@ class ProgramWindow(gtk.Window):
         self.set_skip_pager_hint(True)
         self.set_skip_taskbar_hint(True)
 
-        vbox = gtk.VBox()
+        vbox = gtk.VBox(False, 6)
         vbox.set_border_width(6)
         vbox.pack_start(self.cpt)
         vbox.pack_start(self.upt)
@@ -284,7 +290,7 @@ class ProgramWindow(gtk.Window):
 
         self.config = Configuration()
 
-    def __xmltvfile_loaded(self, xmltvfile, listings):
+    def __xmltvfile_loading_done(self, xmltvfile, listings):
         if listings:
             self.cpt.listings = listings
             self.upt.listings = listings
