@@ -1,7 +1,7 @@
 NAME = 'OnTV'
-VERSION = '1.6.2'
+VERSION = '2.6.0'
 SERVERS_DIR = '/usr/local/lib/bonobo/servers'
-GLADE_DIR = '/usr/local/share/ontv'
-PIXMAPS_DIR = '/usr/local/share/pixmaps'
+DATA_DIR = '/usr/local/share/ontv'
+IMAGES_DIR = '/usr/local/share/ontv/images'
 UI_DIR = '/usr/local/share/gnome-2.0/ui'
 LOCALE_DIR = '/usr/local/share/locale'
